@@ -27,7 +27,6 @@
 
 #include <QString>
 #include <QUrl>
-#include <QVariantMap>
 
 #include <QDateTime>
 
@@ -53,7 +52,7 @@ class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
   public:
     explicit Revision();
     explicit Revision(const Revision &other);
-    virtual ~Revision();
+    ~Revision() override;
 
     /**
      * @brief Returns the id of the revision.
